AuthHandler

Trait AuthHandler 

pub trait AuthHandler: AuthMethodHandler + Send {
    // Provided methods
    fn on_initialization<'life0, 'async_trait>(
        &'life0 mut self,
        initialization: Initialization,
    ) -> Pin<Box<dyn Future<Output = Result<InitializationResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait { ... }
    fn on_start_method<'life0, 'async_trait>(
        &'life0 mut self,
        start_method: StartMethod,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait { ... }
    fn on_finished<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait { ... }
}
Interface for a handler of authentication requests for all methods.

Provided Methods

fn on_initialization<'life0, 'async_trait>( &'life0 mut self, initialization: Initialization, ) -> Pin<Box<dyn Future<Output = Result<InitializationResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Callback when authentication is beginning, providing available authentication methods and returning selected authentication methods to pursue.

fn on_start_method<'life0, 'async_trait>( &'life0 mut self, start_method: StartMethod, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Callback when authentication starts for a specific method.

fn on_finished<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Callback when authentication is finished and no more requests will be received.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors